import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:spotifyplaylistgenerator/config/default_activity_settings.dart';
import 'package:spotifyplaylistgenerator/models/settings/settings_activity.dart';

part 'settings_activity_state.dart';

class ActivitySettingsCubit extends HydratedCubit<ActivitySettingsState> {
  ActivitySettingsCubit()
      : super(ActivitySettingsState(settings: ActivitySettings.createDefault()));

  void setValues({
    String? layout,
  }) {
    emit(
      ActivitySettingsState(
        settings: ActivitySettings(
          layout: layout ?? state.settings.layout,
        ),
      ),
    );
  }

  String getParameterValue(String code) {
    switch (code) {
      case DefaultActivitySettings.parameterCodeLayout:
        return ActivitySettings.getLayoutValueFromUnsafe(state.settings.layout);
    }

    return '';
  }

  void setParameterValue(String code, String value) {
    final String layout = code == DefaultActivitySettings.parameterCodeLayout
        ? value
        : getParameterValue(DefaultActivitySettings.parameterCodeLayout);

    setValues(
      layout: layout,
    );
  }

  @override
  ActivitySettingsState? fromJson(Map<String, dynamic> json) {
    final String layout = json[DefaultActivitySettings.parameterCodeLayout] as String;

    return ActivitySettingsState(
      settings: ActivitySettings(
        layout: layout,
      ),
    );
  }

  @override
  Map<String, dynamic>? toJson(ActivitySettingsState state) {
    return <String, dynamic>{
      DefaultActivitySettings.parameterCodeLayout: state.settings.layout,
    };
  }
}
